@@ -18,8 +18,9 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 package Test::Reporter;
-
+use 5.005;
 use strict;
+BEGIN{ if (not $] < 5.006) { require warnings; warnings->import } }
 use Cwd;
 use Config;
 use Carp;
@@ -33,7 +34,7 @@ use constant FAKE_NO_NET_DNS => 0;    # for debugging only
 use constant FAKE_NO_NET_DOMAIN => 0; # for debugging only
 use constant FAKE_NO_MAIL_SEND => 0;  # for debugging only
 
-$VERSION = '1.51_02';
+$VERSION = '1.53_01';
 
 local $^W = 1;
 
@@ -45,6 +46,8 @@ sub new {
         '_address'           => 'cpan-testers@perl.org',
         '_grade'             => undef,
         '_distribution'      => undef,
+        # XXX distfile => undef would break old clients :-( -- dagolden, 2009-03-30 
+        '_distfile'          => '', 
         '_report'            => undef,
         '_subject'           => undef,
         '_from'              => undef,
@@ -70,7 +73,7 @@ sub new {
 
     $self->{_attr} = {   
         map {$_ => 1} qw(   
-            _address _distribution _comments _errstr _via _timeout _debug _dir
+            _address _distribution _distfile _comments _errstr _via _timeout _debug _dir
         )
     };
 
@@ -118,7 +121,7 @@ sub _process_params {
 
     my %params   = @_;
     my @defaults = qw(
-        mx address grade distribution from comments via timeout debug dir perl_version transport_args transport );
+        mx address grade distribution distfile from comments via timeout debug dir perl_version transport_args transport );
     my %defaults = map {$_ => 1} @defaults;
 
     for my $param (keys %params) {   
@@ -154,9 +157,10 @@ sub report {
     return $self->{_report} if $self->{_report_lock};
 
     my $report;
-    $report .= "This distribution has been tested as part of the cpan-testers\n";
+    $report .= "This distribution has been tested as part of the CPAN Testers\n";
     $report .= "effort to test as many new uploads to CPAN as possible.  See\n";
-    $report .= "http://testers.cpan.org/\n\n";
+    $report .= "http://wiki.cpantesters.org/ for more information or email\n"; 
+    $report .= "questions to cpan-testers-discuss\@perl.org\n\n";
 
     if (not $self->{_comments}) {
         $report .= "\n\n--\n\n";
@@ -344,7 +348,9 @@ sub read {
 
     if (my ($from, $subject, $report) = $buffer =~ /^From:\s(.+)Subject:\s(.+)Report:\s(.+)$/s) {
         my ($grade, $distribution) = (split /\s/, $subject)[0,1];
-        $self->from($from) unless $self->from();
+        chomp($from);
+        chomp($subject);
+        $self->{_from} = $from;
         $self->{_subject} = $subject;
         $self->{_report} = $report;
         $self->{_grade} = lc $grade;
@@ -544,7 +550,7 @@ sub _start_editor {
 
     $editor = $self->_prompt('Editor', $editor);
 
-    die __PACKAGE__, ": The editor `$editor' could not be run" if system "$editor $Report";
+    die __PACKAGE__, ": The editor `$editor' could not be run on '$Report': $!" if system "$editor $Report";
     die __PACKAGE__, ": Report has disappeared; terminated" unless -e $Report;
     die __PACKAGE__, ": Empty report; terminated" unless -s $Report > 2;
 }
@@ -751,14 +757,10 @@ further information visit the below links:
 
 =over 4
 
-=item * L<http://cpantesters.perl.org/>
+=item * L<http://www.cpantesters.org/>
 
 CPAN Testers reports (new site)
 
-=item * L<http://testers.cpan.org/>
-
-CPAN Testers reports (old site)
-
 =item * L<http://cpantest.grango.org/>
 
 The new CPAN Testers Wiki (thanks Barbie!)
@@ -916,7 +918,7 @@ become wrong and you don't have Net::DNS installed.
 
 This constructor returns a Test::Reporter object. It will optionally accept
 named parameters for: mx, address, grade, distribution, from, comments,
-via, timeout, debug, dir, perl_version, and transport.
+via, timeout, debug, dir, perl_version, transport and transport_args.
 
 =item * B<perl_version>
 
