@@ -1,8 +1,8 @@
 use strict;
-use warnings;
+BEGIN{ if (not $] < 5.006) { require warnings; warnings->import } }
 package Test::Reporter::Transport;
 use vars qw/$VERSION/;
-$VERSION = '1.51_02';
+$VERSION = '1.53_01';
 $VERSION = eval $VERSION;
 
 sub new     { die "Not implemented" }
